/**
 * Search configuration with environment variable support
 */
/**
 * Get search limits from environment variables with sensible defaults
 */
export function getSearchLimits() {
    return {
        maxResults: parseInt(process.env.KG_SEARCH_MAX_RESULTS || '100', 10),
        batchSize: parseInt(process.env.KG_SEARCH_BATCH_SIZE || '10', 10),
        maxClientSideEntities: parseInt(process.env.KG_SEARCH_MAX_CLIENT_ENTITIES || '10000', 10),
        clientSideChunkSize: parseInt(process.env.KG_SEARCH_CLIENT_CHUNK_SIZE || '1000', 10)
    };
}
/**
 * Validate search limits to ensure they are within reasonable bounds
 */
export function validateSearchLimits(limits) {
    return {
        maxResults: Math.max(1, Math.min(limits.maxResults, 1000)),
        batchSize: Math.max(1, Math.min(limits.batchSize, 50)),
        maxClientSideEntities: Math.max(100, Math.min(limits.maxClientSideEntities, 100000)),
        clientSideChunkSize: Math.max(100, Math.min(limits.clientSideChunkSize, 10000))
    };
}
/**
 * Get validated search limits
 */
export function getValidatedSearchLimits() {
    return validateSearchLimits(getSearchLimits());
}
//# sourceMappingURL=config.js.map