import { Pool as PgPool } from 'pg';
import { Entity } from '../../core.js';
import { SearchConfig } from '../types.js';
import { BaseSearchStrategy } from './base-strategy.js';
/**
 * PostgreSQL search strategy - supports both database-level and client-side fuzzy search
 */
export declare class PostgreSQLFuzzyStrategy extends BaseSearchStrategy {
    private pgPool;
    private project;
    private searchLimits;
    constructor(config: SearchConfig, pgPool: PgPool, project: string);
    canUseDatabase(): boolean;
    searchDatabase(query: string | string[], threshold: number, project?: string): Promise<Entity[]>;
    private searchSingleDatabase;
    searchClientSide(entities: Entity[], query: string | string[]): Entity[];
    private searchSingleClientSide;
    /**
     * Optimized multiple query search using single SQL query with OR conditions
     * This replaces the inefficient sequential query processing from base strategy
     */
    private searchMultipleDatabaseOptimized;
    /**
     * Handle very large query arrays by processing them in batches
     */
    private searchMultipleDatabaseBatched;
}
//# sourceMappingURL=postgresql-strategy.d.ts.map