/**
 * Multi-Backend Test Runner
 *
 * Provides utilities for running the same test suite against multiple database backends
 * to ensure compatibility and feature parity across SQLite and PostgreSQL.
 */
import { StorageConfig } from '../../storage/types.js';
export interface BackendTestConfig {
    name: string;
    config: StorageConfig;
    available: boolean;
    skipReason?: string;
}
export type TestSuiteFunction = (config: StorageConfig, backendName: string) => void;
/**
 * Configuration for different database backends used in testing
 */
export declare const BACKEND_CONFIGS: BackendTestConfig[];
/**
 * Check if PostgreSQL is available for testing
 */
export declare function checkPostgreSQLAvailability(): Promise<boolean>;
/**
 * Get available backend configurations for testing
 */
export declare function getAvailableBackends(): Promise<BackendTestConfig[]>;
/**
 * Run a test suite against all available backends
 *
 * @param testSuite Function that defines the test suite
 * @param options Configuration options
 */
export declare function runTestsForAllBackends(testSuite: TestSuiteFunction, options?: {
    skipUnavailable?: boolean;
    requireAllBackends?: boolean;
}): void;
/**
 * Run a test suite against only available backends (skips unavailable ones)
 */
export declare function runTestsForAvailableBackends(testSuite: TestSuiteFunction): void;
/**
 * Run a test suite against all backends (fails if any backend is unavailable)
 */
export declare function runTestsForRequiredBackends(testSuite: TestSuiteFunction): void;
/**
 * Utility to create backend-specific test data
 */
export declare function createTestProject(backendName: string, testName: string): string;
/**
 * Utility to add backend-specific test timeouts
 */
export declare function getBackendTimeout(backendName: string): number;
//# sourceMappingURL=multi-backend-runner.d.ts.map